==> nono-0.4.4.tar.gz: nono-0.4.4/debugger/debugger_m680x0.h <==
//
// nono
// Copyright (C) 2020 nono project
// Licensed under nono-license.txt
//

//
// デバッガ (M680x0 依存部分)
//

#pragma once

#include "debugger_private.h"
#include "mpu680x0.h"
#include "m68030.h"
#include "m68030disasm.h"

class DebuggerMD_m680x0 : public DebuggerMD
{
	using inherited = DebuggerMD;
 public:
	DebuggerMD_m680x0(Debugger *parent, m68kcpu *cpu);
	~DebuggerMD_m680x0() override;

	bool IsSuper() const override { return cpu->reg.s; }
	bool MMUEnabled() const override { return cpu->mmu_enable; }
	uint64 TranslateAddr(saddr_t laddr, bool lookup) const override;

	uint32 GetPC() const override { return RegPC; }

	void SetStepOut() override;
	bool IsStepOut() const override;
	bool IsOpStepIn(DebuggerMemoryStream& mem) override;
	uint64 GetRegAddr(const char *name) const override;
	void BackupRegs() override { prev = cpu->reg; }
	bool ShowRegister(FILE *, const std::vector<std::string>& args) override;
	const HelpMessages& GetHelpListReg() const override;
	const HelpMessages& GetHelpReg() const override;

	BranchHistory& GetBrHist() const override { return cpu->brhist; }
	BranchHistory& GetExHist() const override { return cpu->exhist; }

	bool CheckLEA(uint32 laddr) override { return false; }

	std::string Disassemble(DebuggerMemoryStream& mem) override;

 private:
	m68kcpu *cpu {};		// CPU コア
	m68kreg prev {};		// 前回のレジスタセットのコピー

	const char *CondStr(const std::vector<uint16>& ir);
	bool IsOPcc(uint16 op);
	bool IsDBcc(uint16 op);
	bool IsCond(uint16 op);

	static const HelpMessages HelpListReg;
	static const HelpMessages HelpReg;
	void ShowRegMain(FILE *);
	void ShowRegFPU(FILE *);
	void ShowRegMMU(FILE *);
	void ShowRegATC();
	void ShowRegOther();

	uint32 so_a7 {};			// ステップアウト判定用
	uint16 so_sr {};
};

==> nono-0.6.3.tar.gz: nono-0.6.3/debugger/debugger_m680x0.h <==
//
// nono
// Copyright (C) 2020 nono project
// Licensed under nono-license.txt
//

//
// デバッガ (M680x0 依存部分)
//

#pragma once

#include "debugger_private.h"
#include "mpu680x0.h"
#include "m68030disasm.h"

class DebuggerMD_m680x0 : public DebuggerMD
{
	using inherited = DebuggerMD;
 public:
	DebuggerMD_m680x0(Debugger *parent);
	~DebuggerMD_m680x0() override;

	CPUState GetCPUState() const override { return (CPUState)cpu->GetState(); }
	bool IsSuper() const override { return cpu->IsSuper(); }
	bool MMUEnabled() const override { return cpu->mmu_enable; }
	uint64 TranslateAddr(fcaddr laddr, bool lookup) const override;

	uint32 GetPC() const override { return cpu->reg.pc; }

	void SetStepOut() override;
	bool IsStepOut() const override;
	bool IsOpStepIn(DebuggerMemoryStream& mem) override;
	uint64 GetRegAddr(const char *name) const override;
	void BackupRegs() override { prev = cpu->reg; }
	bool ShowRegister(FILE *, const std::vector<std::string>& args) override;
	const HelpMessages& GetHelpListReg() const override;
	const HelpMessages& GetHelpReg() const override;

	bool CheckLEA(uint32 laddr) override { return false; }

	std::string Disassemble(DebuggerMemoryStream& mem) override;

 private:
	MPU680x0Device *cpu {};	// MPU デバイス
	m68kreg prev {};		// 前回のレジスタセットのコピー

	const char *CondStr(const std::vector<uint16>& ir);
	bool IsOPcc(uint16 op);
	bool IsDBcc(uint16 op);
	bool IsCond(uint16 op);

	static const HelpMessages HelpListReg;
	static const HelpMessages HelpReg;
	void ShowRegMain(FILE *);
	void ShowRegFPU(FILE *);
	void ShowRegMMU(FILE *);
	void ShowRegATC();
	void ShowRegOther();

	uint32 so_a7 {};			// ステップアウト判定用
	uint16 so_sr {};
};
